part of flutter_widgetz;

/// {@template flutter_widgetz.ColorPicker}
/// A color picker that represents
/// all [MaterialColor] via a [GridView].
/// {@endtemplate}
class ColorPicker extends StatefulWidget {
  /// {@macro flutter_widgetz.ColorPicker}
  ColorPicker({
    Key? key,
    required this.onTap,
    this.title = 'Choose Color',
    this.initialColor,
    List<Color>? colors,
  }) : super(key: key) {
    this.colors = colors ??
        Colors.primaries.map((MaterialColor color) => color.shade500).toList();
  }

  /// Callback when a color is tapped.
  final ValueChanged<Color> onTap;

  /// A title shown above the picker.
  final String title;

  /// The initial color for the picker.
  final Color? initialColor;

  /// A list of Colors to display.
  ///
  /// Defaults to `Colors.primaries`.
  late final List<Color> colors;

  @override
  State<ColorPicker> createState() => _ColorPickerState();
}

class _ColorPickerState extends State<ColorPicker> {
  Color? _selectedColor;

  @override
  void initState() {
    super.initState();
    _selectedColor = widget.initialColor;
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView(
      slivers: <Widget>[
        SliverToBoxAdapter(
          child: Container(
            padding: const EdgeInsets.all(8.0),
            child: Text(widget.title),
          ),
        ),
        SliverPadding(
          padding: const EdgeInsets.all(16.0),
          sliver: SliverGrid.builder(
            gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(
              maxCrossAxisExtent: 75.0,
              crossAxisSpacing: 10.0,
              mainAxisSpacing: 10.0,
            ),
            itemCount: widget.colors.length,
            itemBuilder: (_, int index) {
              return _Dot(
                color: widget.colors[index],
                isSelected: widget.colors[index] == _selectedColor,
                onTap: _handleTap,
              );
            },
          ),
        ),
      ],
    );
  }

  void _handleTap(Color color) {
    setState(() {
      _selectedColor = color;
    });
    widget.onTap(color);
  }
}

class _Dot extends StatelessWidget {
  const _Dot({
    Key? key,
    required this.color,
    required this.isSelected,
    required this.onTap,
  }) : super(key: key);

  final Color color;
  final bool isSelected;
  final void Function(Color) onTap;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      customBorder: const CircleBorder(),
      onTap: () => onTap(color),
      child: Container(
        height: 50.0,
        width: 50.0,
        decoration: BoxDecoration(
          color: color,
          shape: BoxShape.circle,
          border: Border.all(),
        ),
        child: Center(
          child: isSelected
              ? const Icon(
                  Icons.check,
                  color: Colors.white,
                )
              : const SizedBox(),
        ),
      ),
    );
  }
}
